pub struct SlaterDeterminantProjectionParams {
pub use_magnetic_group: Option<MagneticSymmetryAnalysisKind>,
pub use_double_group: bool,
pub write_character_table: Option<CharacterTableDisplay>,
pub symmetry_transformation_kind: SymmetryTransformationKind,
pub infinite_order_to_finite: Option<u32>,
pub symbolic_projection_targets: Option<Vec<String>>,
pub numeric_projection_targets: Option<Vec<usize>>,
}Expand description
Structure containing control parameters for Slater determinant projection.
Fields
use_magnetic_group: Option<MagneticSymmetryAnalysisKind>Option indicating if the magnetic group is to be used for projection, and if so, whether unitary representations or unitary-antiunitary corepresentations should be used.
use_double_group: boolBoolean indicating if the double group is to be used for symmetry projection.
write_character_table: Option<CharacterTableDisplay>Option indicating if the character table of the group used for symmetry projection is to be printed out.
symmetry_transformation_kind: SymmetryTransformationKindThe kind of symmetry transformation to be applied on the reference Slater determinant to generate the orbit for symmetry projection.
infinite_order_to_finite: Option<u32>The finite order to which any infinite-order symmetry element is reduced, so that a finite subgroup of an infinite group can be used for the symmetry projection.
symbolic_projection_targets: Option<Vec<String>>The projection targets supplied symbolically.
numeric_projection_targets: Option<Vec<usize>>The projection targets supplied numerically, where each value gives the index of the projection subspace based on the group’s character table.
Implementations
Sourceimpl SlaterDeterminantProjectionParams
impl SlaterDeterminantProjectionParams
Sourcepub fn builder() -> SlaterDeterminantProjectionParamsBuilder
pub fn builder() -> SlaterDeterminantProjectionParamsBuilder
Returns a builder to construct a SlaterDeterminantProjectionParams structure.