pub struct SymmetryGroupDetectionParams {
pub moi_thresholds: Vec<f64>,
pub distance_thresholds: Vec<f64>,
pub time_reversal: bool,
pub fictitious_magnetic_fields: Option<Vec<(Point3<f64>, Vector3<f64>)>>,
pub fictitious_electric_fields: Option<Vec<(Point3<f64>, Vector3<f64>)>>,
pub field_origin_com: bool,
pub write_symmetry_elements: bool,
pub result_save_name: Option<PathBuf>,
}Expand description
Structure containing control parameters for symmetry-group detection.
Fields
moi_thresholds: Vec<f64>Thresholds for moment-of-inertia comparisons.
distance_thresholds: Vec<f64>Thresholds for distance and geometry comparisons.
time_reversal: boolBoolean indicating if time reversal is to be taken into account.
fictitious_magnetic_fields: Option<Vec<(Point3<f64>, Vector3<f64>)>>Fictitious magnetic fields to be added to the system. Each magnetic field is specified by an
origin $\mathbf{O}$ and a vector $\mathbf{v}$, for which a magnetic(+) special atom
will be added at $\mathbf{O} + \mathbf{v}$, and a magnetic(-) special atom will be
added at $\mathbf{O} - \mathbf{v}$.
fictitious_electric_fields: Option<Vec<(Point3<f64>, Vector3<f64>)>>Fictitious electric fields to be added to the system. Each electric field is specified by an
origin $\mathbf{O}$ and a vector $\mathbf{v}$, for which an electric(+) special atom
will be added at $\mathbf{O} + \mathbf{v}$.
field_origin_com: boolBoolean indicating if the origins specified in Self::fictitious_magnetic_fields and
Self::fictitious_electric_fields are to be taken relative to the molecule’s centre of
mass rather than to the space-fixed origin.
write_symmetry_elements: boolBoolean indicating if a summary of the located symmetry elements is to be written to the output file.
result_save_name: Option<PathBuf>Optional name for saving the result as a binary file of type QSym2FileType::Sym. If
None, the result will not be saved.
Implementations
Sourceimpl SymmetryGroupDetectionParams
impl SymmetryGroupDetectionParams
Sourcepub fn builder() -> SymmetryGroupDetectionParamsBuilder
pub fn builder() -> SymmetryGroupDetectionParamsBuilder
Returns a builder to construct a SymmetryGroupDetectionParams structure.