pub struct BinariesSlaterDeterminantSource {
pub xyz: PathBuf,
pub sao: PathBuf,
pub sao_4c: Option<PathBuf>,
pub coefficients: Vec<PathBuf>,
pub occupations: Vec<PathBuf>,
pub baos: Vec<InputBasisAngularOrder>,
pub spin_constraint: SpinConstraint,
pub matrix_order: MatrixOrder,
pub byte_order: ByteOrder,
}Expand description
Serialisable/deserialisable structure containing control parameters for acquiring Slater determinant(s) from a custom specification.
Fields
xyz: PathBufPath to an XYZ file containing the molecular geometry.
sao: PathBufPath to a binary file containing the two-centre atomic-orbital spatial overlap matrix.
sao_4c: Option<PathBuf>Optional path to a binary file containing the four-centre atomic-orbital spatial overlap matrix. This is only required for density symmetry analysis.
coefficients: Vec<PathBuf>Paths to binary files containing molecular-orbital coefficient matrices for different spin spaces.
occupations: Vec<PathBuf>Paths to binary files containing occupation numbers for the molecular orbitals.
baos: Vec<InputBasisAngularOrder>Specifications of basis angular order information, one for each explicit component per coefficient matrix.
spin_constraint: SpinConstraintSpecification of spin constraint.
matrix_order: MatrixOrderSpecification of the order matrix elements are packed in binary files.
byte_order: ByteOrderSpecification of the byte order numerical values are stored in binary files.
Implementations
Sourceimpl BinariesSlaterDeterminantSource
impl BinariesSlaterDeterminantSource
Sourcepub fn builder() -> BinariesSlaterDeterminantSourceBuilder
pub fn builder() -> BinariesSlaterDeterminantSourceBuilder
Returns a builder to construct a structure for handling binaries Slater determinant source.