pub enum InputShellOrder {
PureIncreasingm,
PureDecreasingm,
PureCustom(Vec<i32>),
CartLexicographic,
CartQChem,
CartCustom(Vec<(u32, u32, u32)>),
SpinorFermionIncreasingm(bool, Option<SpinorBalanceSymmetry>),
SpinorFermionDecreasingm(bool, Option<SpinorBalanceSymmetry>),
SpinorFermionCustom(bool, Vec<i32>, Option<SpinorBalanceSymmetry>),
SpinorAntifermionIncreasingm(bool, Option<SpinorBalanceSymmetry>),
SpinorAntifermionDecreasingm(bool, Option<SpinorBalanceSymmetry>),
SpinorAntifermionCustom(bool, Vec<i32>, Option<SpinorBalanceSymmetry>),
}Expand description
Serialisable/deserialisable enumerated type to indicate the type of the angular functions in a shell and how they are ordered.
Variants
PureIncreasingm
This variant indicates that the angular functions are real solid harmonics arranged in
increasing $m$ order.
PureDecreasingm
This variant indicates that the angular functions are real solid harmonics arranged in
decreasing $m$ order.
PureCustom(Vec<i32>)
This variant indicates that the angular functions are real solid harmonics arranged in
a custom order specified by the $m_l$ values.
CartLexicographic
This variant indicates that the angular functions are Cartesian functions arranged in lexicographic order.
CartQChem
This variant indicates that the angular functions are Cartesian functions arranged in Q-Chem order.
CartCustom(Vec<(u32, u32, u32)>)
This variant indicates that the angular functions are Cartesian functions arranged in a custom order specified by the ordered exponent tuples.
SpinorFermionIncreasingm(bool, Option<SpinorBalanceSymmetry>)
This variant indicates that the angular functions are spinors describing a fermion arranged
in increasing $m$ order. The associated boolean indicates whether the spinors are even
with respect to spatial inversion.
SpinorFermionDecreasingm(bool, Option<SpinorBalanceSymmetry>)
This variant indicates that the angular functions are spinors describing a fermion arranged
in decreasing $m$ order. The associated boolean indicates whether the spinors are even
with respect to spatial inversion.
SpinorFermionCustom(bool, Vec<i32>, Option<SpinorBalanceSymmetry>)
This variant indicates that the angular functions are spinors describing a fermion arranged
in a custom order specified by the $m_l$ values.
SpinorAntifermionIncreasingm(bool, Option<SpinorBalanceSymmetry>)
This variant indicates that the angular functions are spinors describing an antifermion
arranged in increasing $m$ order. The associated boolean indicates whether the spinors are
even with respect to spatial inversion.
SpinorAntifermionDecreasingm(bool, Option<SpinorBalanceSymmetry>)
This variant indicates that the angular functions are spinors describing an antifermion
arranged in decreasing $m$ order. The associated boolean indicates whether the spinors are
even with respect to spatial inversion.
SpinorAntifermionCustom(bool, Vec<i32>, Option<SpinorBalanceSymmetry>)
This variant indicates that the angular functions are spinors describing an antifermion
arranged in a custom order specified by the $m_l$ values.
Implementations
Sourceimpl InputShellOrder
impl InputShellOrder
Sourcepub fn to_shell_order(&self, l: u32) -> ShellOrder
pub fn to_shell_order(&self, l: u32) -> ShellOrder
Converts the InputShellOrder to a corresponding ShellOrder.