pub struct Symmetry {
pub group_name: Option<String>,
/* private fields */
}Expand description
Structure for storing and managing symmetry analysis results.
Fields
group_name: Option<String>The determined point group in Schönflies notation.
Implementations
Sourceimpl Symmetry
impl Symmetry
Sourcepub fn builder() -> SymmetryBuilder
pub fn builder() -> SymmetryBuilder
Returns a builder to construct a new symmetry struct.
Returns
A builder to construct a new symmetry struct.
Sourcepub fn analyse(
&mut self,
presym: &PreSymmetry,
tr: bool,
) -> Result<&mut Self, Error>
pub fn analyse( &mut self, presym: &PreSymmetry, tr: bool, ) -> Result<&mut Self, Error>
Performs point-group detection analysis and populates the fields in this structure with the results.
Arguments
presym- A pre-symmetry-analysis structure containing the molecule and its rotational symmetry required for point-group detection.tr- A boolean indicating if time reversal should also be considered. A time-reversed symmetry element will only be considered if its non-time-reversed version turns out to be not a symmetry element.
Sourcepub fn get_elements(
&self,
kind: &SymmetryElementKind,
) -> Option<&HashMap<ElementOrder, IndexSet<SymmetryElement>>>
pub fn get_elements( &self, kind: &SymmetryElementKind, ) -> Option<&HashMap<ElementOrder, IndexSet<SymmetryElement>>>
Sourcepub fn get_elements_mut(
&mut self,
kind: &SymmetryElementKind,
) -> Option<&mut HashMap<ElementOrder, IndexSet<SymmetryElement>>>
pub fn get_elements_mut( &mut self, kind: &SymmetryElementKind, ) -> Option<&mut HashMap<ElementOrder, IndexSet<SymmetryElement>>>
Sourcepub fn get_generators(
&self,
kind: &SymmetryElementKind,
) -> Option<&HashMap<ElementOrder, IndexSet<SymmetryElement>>>
pub fn get_generators( &self, kind: &SymmetryElementKind, ) -> Option<&HashMap<ElementOrder, IndexSet<SymmetryElement>>>
Sourcepub fn get_generators_mut(
&mut self,
kind: &SymmetryElementKind,
) -> Option<&mut HashMap<ElementOrder, IndexSet<SymmetryElement>>>
pub fn get_generators_mut( &mut self, kind: &SymmetryElementKind, ) -> Option<&mut HashMap<ElementOrder, IndexSet<SymmetryElement>>>
Sourcepub fn get_sigma_elements(
&self,
sigma: &str,
) -> Option<HashSet<&SymmetryElement>>
pub fn get_sigma_elements( &self, sigma: &str, ) -> Option<HashSet<&SymmetryElement>>
Obtains mirror-plane elements by their type ("h", "v", "d", or ""), including both
time-reversed and non-time-reversed variants.
Arguments
sigma- The mirror-plane type which is one of"h","v","d", or"".
Returns
An option containing the set of the required mirror-plane element type, if exists. If not,
then None is returned.
Sourcepub fn get_sigma_generators(
&self,
sigma: &str,
) -> Option<HashSet<&SymmetryElement>>
pub fn get_sigma_generators( &self, sigma: &str, ) -> Option<HashSet<&SymmetryElement>>
Sourcepub fn get_max_proper_order(&self) -> ElementOrder
pub fn get_max_proper_order(&self) -> ElementOrder
Sourcepub fn get_proper(
&self,
order: &ElementOrder,
) -> Option<HashSet<&SymmetryElement>>
pub fn get_proper( &self, order: &ElementOrder, ) -> Option<HashSet<&SymmetryElement>>
Sourcepub fn get_improper(
&self,
order: &ElementOrder,
) -> Option<HashSet<&SymmetryElement>>
pub fn get_improper( &self, order: &ElementOrder, ) -> Option<HashSet<&SymmetryElement>>
Sourcepub fn get_proper_principal_element(&self) -> &SymmetryElement
pub fn get_proper_principal_element(&self) -> &SymmetryElement
Obtains a proper principal element, i.e. a time-reversed or non-time-reversed proper element with the highest order.
If there are several such elements, the element to be returned will be randomly chosen but with any non-time-reversed ones prioritised.
Returns
A proper principal element.
Panics
Panics if no proper elements or generators can be found.
Sourcepub fn is_infinite(&self) -> bool
pub fn is_infinite(&self) -> bool
Determines if this group is an infinite group.
Returns
A boolean indicating if this group is an infinite group.
Sourcepub fn n_elements(&self) -> usize
pub fn n_elements(&self) -> usize
Returns the total number of symmetry elements (NOT symmetry operations). In infinite-order groups, this is the sum of the number of discrete symmetry elements and the number of discrete symmetry generators.
Sourcepub fn generate_all_operations(
&self,
infinite_order_to_finite: Option<u32>,
) -> Vec<SymmetryOperation>
pub fn generate_all_operations( &self, infinite_order_to_finite: Option<u32>, ) -> Vec<SymmetryOperation>
Generates all possible symmetry operations from the available symmetry elements.
Arguments
infinite_order_to_finite- A finite order to interpret infinite-order generators of infinite groups.
Returns
A vector of generated symmetry operations.
Panics
Panics if the group is infinite but infinite_order_to_finite is None, or if the finite
order specified in infinite_order_to_finite is incompatible with the infinite group.